# Application Structure

- [Introduction](#introduction)
- [The Root Directory](#the-root-directory)
- [Laravel Structure](#laravel-structure)

<a name="introduction"></a>
## Introduction

The default application structure is intended to provide a modular environment for both large and small applications. Of course, you are free to use Laravel-like class organization, it is highly encouraged to organize your classes and logic into `addons` in order to turbocharge your application development and promote solid design principles.

<a name="the-root-directory"></a>
## The Root Directory

The root directory of a fresh installation mirrors Laravel almost verbatim and also adds a few extra directories:

The `addons` directory contains your `shared` and `private` addons. Shared addons are located in `addons/shared` and private addons in `addons/example` where example is your application's reference slug. Furthermore, just like the `core` directory below, addons are organized within their `vendor` directories. For example your company's private module might be located at `addons/my_company/example-module`.

The `app` directory, as you might expect from Laravel, should be used sparingly. For best results, organize your code into addons.

The `bootstrap` folder contains a few files that bootstrap the Laravel framework and configure autoloading, as well as a `cache` folder that contains a few framework generated files for bootstrap performance optimization.

The `config` directory, as the name implies, contains all of your application's configuration files and the configuration override files for Streams Platform and all of your addons. **Note: addons also support a `config` directory within their `resources` directory.**

The `core` directory contains all of your applications core addons. Any `streams-addon` package that is required in your `composer.json` file will be stored here. Once you have installed your application you will notice that all addon's are organized into `vendor` directories within the `core` directory. Much like the `vendor` directory below.

The `database` folder contains your database migration and seeds. If you wish, you may also use this folder to hold an SQLite database. **Note: addons also support storage of migrations and seeds.**

The `public` directory contains the front controller and your assets (images, JavaScript, CSS, etc.). The `Image` and `Asset` managers will dump cached output to `public/assets/example/cache`.

The `resources` directory contains your views, raw assets (LESS, SASS, CoffeeScript), and localization files. **Note: addons also support `resources` directories.**

The `storage` directory contains compiled view templates, file based sessions, file caches, compiled Streams models, and other files generated by the framework. This folder is segregated into `app`, `framework`, `logs`, and `streams` directories. The `app` directory may be used to store any files utilized by your application. The `framework` directory is used to store framework generated files and caches, the `logs` directory contains your application's log files, and the `streams` directory contains internally generated models, field type assets, and other addon generated resources.

The `tests` directory contains your automated tests. An example [PHPUnit](https://phpunit.de/) is provided out of the box.

The `vendor` directory contains your [Composer](https://getcomposer.org) dependencies. The Streams Platform is located in `vendor/anomaly/streams-platform`.


<a name="laravel-structure"></a>
## Laravel Structure

While your application should be organized into addons, each containing their relevant logic, classes, migrations, etc; you may also use Laravel's native application structure as needed. Note that some automations and features of Streams Platform may not behave the same outside of the context of addons.

For more information on Laravel's `App` folder and general organization please refer to the [Laravel documentation](http://laravel.com/docs/5.1/structure#the-app-directory).
